==> eh-0.4.tar.gz: eh-0.4/src/ehhexdmp.c <==
/***

ehhexdmp.c -- Error Handler, hex dump of the specified block of memory.

Copyright (c) 1992-6 Christopher Cobb, All rights reserved.

***/

static const char *rcsid =
       "$Id: ehhexdmp.c,v 1.3 1995/08/16 19:48:21 ccobb Exp $";

#include "ehenv.h"

EHBEGINEXTERNC
#include <ctype.h>
EHENDEXTERNC

//#include "ehpgmtrc.h"
#include "ehhexdmp.h"

#define hexc(x) '0' + ((x) > 9 ? (x) + 7 : (x))/* hex nibble to ASCII */

FILENAME("ehhexdmp.c");

/***
ehHexDmp()
Dump memory block in hex and ascii 
***/

void 
ehHexDmp A3(FILE*,        pFileOut, /* where to write */
            const char *, pcData,   /* start of block */
            int,          iNum)     /* number of bytes to dump */
{
   int  j;
   const char *p = pcData;                   /* ascii pointer */
   int  n  = iNum;
   char x;

   while (iNum > 0)
   {
      /*** address ***/

      fprintf(pFileOut, "%08lx:  ", (long)p);
      fflush(pFileOut);

      /*** hex part ***/

      for (j = 0; j < 16; j++)          /* first hex */
      {
         if (n <= 0)
            fprintf(pFileOut, "   ");        /* count exhausted */
         else  
         {
            x = (char)((*p >> 4) & 0x0f);   /* display 2 hex digits */
            fprintf(pFileOut, "%c", hexc(x));
            x = (char)(*p++ & 0x0f);
            fprintf(pFileOut, "%c", hexc(x));
            fprintf(pFileOut, " ");
            --n;
         }
         fflush(pFileOut);
      }
      fflush(pFileOut);

      /*** asciii part ***/

      fprintf(pFileOut, "   ");                /* then ascii */
      for (j=0; j<16; j++)
      {
         if (iNum <= 0)
            break;
         x = (char)(*pcData++ & 0x7f);
         fprintf(pFileOut, "%c", isprint((int)x) ? x : '.');
         --iNum;
         fflush(pFileOut);
      }
      fprintf(pFileOut, "\n");
      fflush(pFileOut);
   }

   fflush(pFileOut);
   return;
}

#if 0 /* def MAIN */

int  main ARGS((void));

int  main(argc, argv)   /****   test harness   ****/
int argc;
char *argv[];
{
   char *pc="0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";

   PGM_ENTER();

   ehHexDmp(pc,  0);
   ehHexDmp(pc,  1);
   ehHexDmp(pc, 15);
   ehHexDmp(pc, 16);
   ehHexDmp(pc, 17);
   ehHexDmp(pc, 61);
   ehHexDmp(pc, 62);
   ehHexDmp(pc, 63);

   PGM_RETURN(0);
}

#endif

==> eh-0.5.tar.gz: eh-0.5/src/ehhexdmp.c <==
/***

ehhexdmp.c -- Error Handler, hex dump of the specified block of memory.

    Copyright (C) 1997  CSEG, Inc., All rights reserved.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                   

    The GNU General Public License is in the file COPYING which resides
    in the top directory of the distribution tree.

***/

static const char *rcsid =
       "$Id: ehhexdmp.c,v 1.3 1995/08/16 19:48:21 ccobb Exp $";

#include "ehhexdmp.h"

EHBEGINEXTERNC
#include <ctype.h>
EHENDEXTERNC

//#include "ehpgmtrc.h"

#define hexc(x) '0' + ((x) > 9 ? (x) + 7 : (x))/* hex nibble to ASCII */

EHFILENAME("ehhexdmp.c");

/***
ehHexDmp()
Dump memory block in hex and ascii 
***/

void 
ehHexDmp A3(FILE*,        pFileOut, /* where to write */
            const char *, pcData,   /* start of block */
            int,          iNum)     /* number of bytes to dump */
{
   int  j;
   const char *p = pcData;                   /* ascii pointer */
   int  n  = iNum;
   char x;

   while (iNum > 0)
   {
      /*** address ***/

      fprintf(pFileOut, "%08lx:  ", (long)p);
      fflush(pFileOut);

      /*** hex part ***/

      for (j = 0; j < 16; j++)          /* first hex */
      {
         if (n <= 0)
            fprintf(pFileOut, "   ");        /* count exhausted */
         else  
         {
            x = (char)((*p >> 4) & 0x0f);   /* display 2 hex digits */
            fprintf(pFileOut, "%c", hexc(x));
            x = (char)(*p++ & 0x0f);
            fprintf(pFileOut, "%c", hexc(x));
            fprintf(pFileOut, " ");
            --n;
         }
         fflush(pFileOut);
      }
      fflush(pFileOut);

      /*** asciii part ***/

      fprintf(pFileOut, "   ");                /* then ascii */
      for (j=0; j<16; j++)
      {
         if (iNum <= 0)
            break;
         x = (char)(*pcData++ & 0x7f);
         fprintf(pFileOut, "%c", isprint((int)x) ? x : '.');
         --iNum;
         fflush(pFileOut);
      }
      fprintf(pFileOut, "\n");
      fflush(pFileOut);
   }

   fflush(pFileOut);
   return;
}

#if 0 /* def MAIN */

int  main ARGS((void));

int  main(argc, argv)   /****   test harness   ****/
int argc;
char *argv[];
{
   char *pc="0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";

   PGM_ENTER();

   ehHexDmp(pc,  0);
   ehHexDmp(pc,  1);
   ehHexDmp(pc, 15);
   ehHexDmp(pc, 16);
   ehHexDmp(pc, 17);
   ehHexDmp(pc, 61);
   ehHexDmp(pc, 62);
   ehHexDmp(pc, 63);

   PGM_RETURN(0);
}

#endif
